# REQ

_REQ_ is a command line program written in [Java](https://docs.oracle.com/javase/8/docs/technotes/guides/language/index.html) that allows estimating the rate of elementary quartets (REQ) for each internal branch of a phylogenetic tree from a distance matrix, as described by [Guénoche and Garreta (2001)](https://doi.org/10.1007/3-540-45727-5_5).

## Compilation and execution

The source code of _REQ_ is inside the _src_ directory and could be compiled and executed in two different ways. 

#### Building an executable jar file

On computers with [Oracle JDK](http://www.oracle.com/technetwork/java/javase/downloads/index.html) (6 or higher) installed, a Java executable jar file could be created. In a command-line window, go to the _src_ directory and type:
```bash
javac REQ.java 
echo Main-Class: REQ > MANIFEST.MF 
jar -cmvf MANIFEST.MF REQ.jar REQ.class 
rm MANIFEST.MF REQ.class 
```
This will create the executable jar file `REQ.jar` that could be launched with the following command line model:
```bash
java -jar REQ.jar [files]
```

#### Building a native executable

On computers with [GraalVM](hhttps://www.graalvm.org/downloads/) installed, a native executable could also be built. In a command-line window, go to the _src_ directory, and type:
```bash
javac REQ.java 
native-image -H:Name=REQ -H:-MultiThreaded REQ
rm REQ.class
```
This will create the native executable `REQ` that could be launched with the following command line model:
```bash
./REQ [files]
```

## Usage

Launch _REQ_ without option to read the following documentation:

```
 USAGE:  REQ  <dfile>  <tfile>  <outfile>  [-v]

   <dfile>    distance matrix file in either PHYLIP lower-triangular or
              square format
   <tfile>    unrooted binary phylogenetic tree file with no confidence
              value at branches in NEWICK format
   <outfile>  outfile name
   -v         verbose mode
```

## Example

The directory _example_ contains two files from the study of [Garcia-Hermoso et al. (2018)](https://doi.org/10.1128/mBio.00573-18):     
* _matrix.d_: a distance matrix in PHYLIP square format estimated from 22 _Mucor circinelloides_ f. _circinelloides_ genomes,
* _tree.t_: the associated minimum-evolution phylogenetic tree in NEWICK format.

The following command line writes into the file _tree.req.t_ the phylogenetic tree from _example/tree.t_ with the rate of elementary quartets at each internal branch estimated from the distance matrix _example/matrix.d_:
```bash
REQ  example/matrix.d  example/tree.t  tree.req.t  -v
```
Because the option `-v` is set, the verbose mode will output the tree topology in NEWICK format, the list of leaf names, and, for each internal branch, the leaf quadripartition following by the rate of elementary quartets _Re_:
```
# (((((((17,18),16),((20,21),19)),(((4,((6,7),5)),(((2,3),1),0)),(8,9))),(10,11)),(12,13)),14,15);
0: P07_621_SLS
1: 1006PHL
2: P08_701_BU2_PER
3: P01_617_BU1_SLS
4: P11_702_BU2_PER
5: E01_615_SLS
6: P04_601_BU1_SLS
7: P04_559_BU1_SLS
8: P05_600_BU1_SLS
9: P05_598_BU1_SLS
10: P04_603_BU1_SLS
11: P04_602_BU1_SLS
12: P06_032_BU1_SLS
13: P06_023_BU1_SLS
14: P02_783_BU1_SLS
15: P12_579_STR
16: P05_622_BU1_SLS
17: P10_703_BU2_PER
18: P09_704_BU2_PER
19: P03_594_BU1_SLS
20: P05_599_BU1_SLS
21: P03_592_BU1_SLS
[17][18][16][21,20,19,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0] Re=1.000 (19/19)
[18,17][16][19,21,20][15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0] Re=0.677 (65/96)
[20][21][19][18,17,16,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0] Re=0.474 (9/19)
[21,20][19][16,18,17][15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0] Re=1.000 (96/96)
[16,18,17][19,21,20][9,8,0,1,3,2,5,7,6,4][15,14,13,12,11,10] Re=0.856 (462/540)
[6][7][5][21,20,19,18,17,16,15,14,13,12,11,10,9,8,4,3,2,1,0] Re=1.000 (19/19)
[7,6][5][4][21,20,19,18,17,16,15,14,13,12,11,10,9,8,3,2,1,0] Re=0.944 (34/36)
[4][5,7,6][0,1,3,2][21,20,19,18,17,16,15,14,13,12,11,10,9,8] Re=1.000 (168/168)
[2][3][1][21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,4,0] Re=1.000 (19/19)
[3,2][1][0][21,20,19,18,17,16,15,14,13,12,11,10,9,8,7,6,5,4] Re=1.000 (36/36)
[1,3,2][0][5,7,6,4][21,20,19,18,17,16,15,14,13,12,11,10,9,8] Re=1.000 (168/168)
[5,7,6,4][0,1,3,2][9,8][21,20,19,18,17,16,15,14,13,12,11,10] Re=1.000 (384/384)
[8][9][0,1,3,2,5,7,6,4][21,20,19,18,17,16,15,14,13,12,11,10] Re=1.000 (96/96)
[0,1,3,2,5,7,6,4][9,8][19,21,20,16,18,17][15,14,13,12,11,10] Re=0.453 (261/576)
[19,21,20,16,18,17][9,8,0,1,3,2,5,7,6,4][11,10][15,14,13,12] Re=0.487 (234/480)
[10][11][9,8,0,1,3,2,5,7,6,4,19,21,20,16,18,17][15,14,13,12] Re=1.000 (64/64)
[9,8,0,1,3,2,5,7,6,4,19,21,20,16,18,17][11,10][13,12][15,14] Re=0.594 (76/128)
[12][13][11,10,9,8,0,1,3,2,5,7,6,4,19,21,20,16,18,17][15,14] Re=1.000 (36/36)
[11,10,9,8,0,1,3,2,5,7,6,4,19,21,20,16,18,17][13,12][14][15] Re=0.500 (18/36)
output tree written into tree.req.t
```

Of note, the output file _tree.req.t_ is available inside the directory _example_.

## References

Garcia-Hermoso D, Criscuolo A, Lee SC, Legrand M, Chaouat M, Denis B, Lafaurie M, Rouveau M, Soler C, Schaal JV, Mimoun M, Mebazaa A, Heitman J, Dromer F, Brisse S, Bretagne S, Alanio A (2018) Outbreak of invasive wound mucormycosis in a burn unit due to multiple strains of _Mucor circinelloides_ f. _circinelloides_ resolved by whole-genome sequencing. MBio, 24;9(2):e00573-18. [doi:10.1128/mBio.00573-18](https://doi.org/10.1128/mBio.00573-18).

Guénoche A, Garreta H (2001) Can we have confidence in a tree representation? _In_: Gascuel O, Sagot MF (eds) Computational Biology. Lecture Notes in Computer Science, vol 2066. Springer, Berlin, Heidelberg. [doi:10.1007/3-540-45727-5_5](https://doi.org/10.1007/3-540-45727-5_5). [[pdf]](http://iml.univ-mrs.fr/editions/biblio/guenoche/QualiTree-1.pdf)
